#
# spec file for package python-flufl.lock
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-flufl.lock
Version:        8.0.2
Release:        bp156.1.1
Summary:        NFS-safe file locking with timeouts for POSIX and Windows
License:        Apache-2.0
URL:            https://gitlab.com/warsaw/flufl.lock
Source:         https://files.pythonhosted.org/packages/source/f/flufl.lock/flufl_lock-%{version}.tar.gz
BuildRequires:  %{python_module atpublic >= 2.3}
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pdm-backend}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module psutil >= 5.9}
BuildRequires:  %{python_module typing_extensions if %python-base < 3.8}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-atpublic >= 2.3
Requires:       python-psutil >= 5.9
Requires:       (python-typing_extensions if python-base < 3.8)
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module sybil}
# /SECTION
%python_subpackages

%description
NFS-safe file locking with timeouts for POSIX and Windows.

%prep
%autosetup -p1 -n flufl_lock-%{version}
sed -i 's/--cov=flufl --cov-report=term --cov-report=xml//' pyproject.toml

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst docs/NEWS.rst
%license LICENSE
%dir %{python_sitelib}/flufl
%{python_sitelib}/flufl/lock
%{python_sitelib}/flufl_lock-%{version}.dist-info

%changelog
* Fri Jan  5 2024 Dirk Müller <dmueller@suse.com>
- update to 8.0.2:
  * Update dependencies.
  * Other minor improvements and cleanups.
  * Minor documentation fix.
  * Drop Python 3.7 support (GL#34)
  * Added a claimfile property to Lock objects
  * Switch to pdm- ackend (GL#33)
  * Use ruff for linting, since its much faster.
* Mon Jun 12 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Wed Dec 21 2022 Ben Greiner <code@bnavigator.de>
- Fix requirements
- Remove coverage flags from testsuite
* Wed Sep 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 7.1.1 (2022-09-03)
  * Improvements to the GitLab CI integration.
- Update to 7.1 (2022-08-27)
  * Add support for Python 3.11.
  * Update to pdm 1.3.
  * Update all dependencies eagerly.
* Wed Aug 31 2022 Markéta Machová <mmachova@suse.com>
- Fix build dependencies
* Thu Jan 20 2022 Matej Cepl <mcepl@suse.com>
- Update to 7.0:
  - Fix spurious log messages when not breaking the lock.
  - Use modern package management by adopting pdm and
    pyproject.toml, and dropping setup.py and setup.cfg.
  - Build the docs with Python 3.8.
  - Update to version 3.0 of Sybil.
  - Adopt the Furo documentation theme.
  - Add a favicon and logos to the published documentation.
  - Use importlib.metadata.version() as a better way to get the
    package version number for the documentation.
  - Drop Python 3.6 support.
  - Update copyright years.
- Remove now irrelevant patch python-flufl.lock-fix-setup.patch.
* Wed Nov 17 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 6.0
  * Added a default_timeout argument to the Lock constructor,
    which can be used in the context manager syntax as well.
  * When a Lock uses a lock file that already exists and does
    not appear to be a lock file (i.e. because its contents are
    ill-formatted), do a better job of not clobbering that file.
  * Improve some QA by re-adding diff-cover, Gitlab SAST during
    CI, and testing on Python 3.10 beta (except for Windows)
  * Added a py.typed file to satisfy type checkers.
* Tue May 25 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 5.0.5
  * Blued code.
* Fri Feb 12 2021 Andreas Schneider <asn@cryptomilk.org>
- The package Requires python-typing_extensions
* Thu Feb 11 2021 Andreas Schneider <asn@cryptomilk.org>
- Add missing python-typing_extensions BuildRequires for tests
* Thu Feb 11 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 5.0.4
  * https://gitlab.com/warsaw/flufl.lock/-/blob/5.0.4/docs/NEWS.rst
- Removed LICENSE (part of the tarball now)
- Added python-flufl.lock-fix-setup.patch
* Mon Dec  2 2019 pgajdos@suse.com
- call spec-cleaner
* Thu Sep 26 2019 pgajdos@suse.com
- initial version 3.2, required by python-mailman [SLE-7686]
